==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/DeleteChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest = {
    import DeleteChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteChannelRequest.wrap(buildAwsValue())
}
object DeleteChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteChannelRequest =
      zio.aws.mediatailor.model.DeleteChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ) extends zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ): zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.206.1-sources.jar: zio/aws/mediatailor/model/DeleteChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest = {
    import DeleteChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteChannelRequest.wrap(buildAwsValue())
}
object DeleteChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteChannelRequest =
      zio.aws.mediatailor.model.DeleteChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ) extends zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteChannelRequest
  ): zio.aws.mediatailor.model.DeleteChannelRequest.ReadOnly = new Wrapper(impl)
}
